<?php

/**
 * Form constructor for settings administration.
 *
 * @see opinion_monitor_admin_form_submit()
 */
function opinion_monitor_admin_form($state) {
  $form = array();
  $form['wysiwyg_info'] = array(
    '#value' => '<p>If you use a WYSIWYG editor module, such as CKEditor, please ensure that you add the text areas on this page to the editor\'s exclusion list.</p>',
  );
  $form['metrics'] = array(
    '#type' => 'fieldset',
    '#tree' => TRUE,
    '#title' => check_plain('Metrics'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
    '#description' => 'User metric field values.',
  );
  $form['metrics']['gender'] = array(
    '#type' => 'textarea',
    '#title' => t('Gender'),
    '#default_value' => variable_get('opinion_monitor_metrics_gender', ''),
    '#required' => FALSE,
    '#description' => 'Type a list of available genders, one per line. To disable the gender selection metric, completely empty this box.',
  );
  $form['metrics']['age'] = array(
    '#type' => 'textarea',
    '#title' => t('Age'),
    '#default_value' => variable_get('opinion_monitor_metrics_age', ''),
    '#required' => FALSE,
    '#description' => 'Type a list of available ages, one per line. To disable the age selection metric, completely empty this box.',
  );
  $form['metrics']['location'] = array(
    '#type' => 'textarea',
    '#title' => t('Location'),
    '#default_value' => variable_get('opinion_monitor_metrics_location', ''),
    '#required' => FALSE,
    '#description' => 'Type a list of available locations, one per line. To disable the location selection metric, completely empty this box.',
  );
  $form['chart'] = array(
    '#type' => 'fieldset',
    '#tree' => TRUE,
    '#title' => check_plain('Chart'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
    '#description' => 'Chart display settings.',
  );
  $form['chart']['line_color_user'] = array(
    '#type' => 'textfield',
    '#title' => t('Line Color (User)'),
    '#default_value' => variable_get('opinion_monitor_chart_line_color_user', ''),
    '#required' => TRUE,
    '#description' => 'Type the HTML color value to use for the user chart series. To use the default value, empty this box.',
  );
  $form['chart']['line_color_average'] = array(
    '#type' => 'textfield',
    '#title' => t('Line Color (Average)'),
    '#default_value' => variable_get('opinion_monitor_chart_line_color_average', ''),
    '#required' => TRUE,
    '#description' => 'Type the HTML color value to use for the average chart series. To use the default value, empty this box.',
  );
  $form['misc'] = array(
    '#type' => 'fieldset',
    '#tree' => TRUE,
    '#title' => check_plain('Miscellaneous Settings'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
    '#description' => 'Miscellaneous Opinion Monitor module settings.',
  );
  $form['misc']['use_module_css'] = array(
    '#type' => 'select',
    '#options' => array(
      1 => 'Use the module\'s CSS styles',
      0 => 'I will provide custom CSS styles',
    ),
    '#title' => t('Opinion Monitor Styles'),
    '#default_value' => variable_get('opinion_monitor_use_module_css', 1),
    '#required' => TRUE,
    '#description' => 'This module comes with a default CSS file for styling Opinion Monitor content. Change this value if you wish to use your own CSS.',
  );
  $form['misc']['use_drupal_jquery'] = array(
    '#type' => 'select',
    '#options' => array(
      1 => 'Use Drupal\'s jQuery UI files',
      0 => 'I will provide jQuery UI files',
    ),
    '#title' => t('Drupal jQuery UI Files'),
    '#default_value' => variable_get('opinion_monitor_use_drupal_jquery', 1),
    '#required' => TRUE,
    '#description' => 'By default, this module uses the jQuery UI file from the module of the same name. Change this value if you intend to include your own jQuery UI installation.',
  );
  $form['misc']['user_metrics_location'] = array(
    '#type' => 'select',
    '#options' => array(
      'above' => 'Before content',
      'below' => 'After content',
    ),
    '#title' => t('Location of user metrics form'),
    '#default_value' => variable_get('opinion_monitor_user_metrics_location', 'below'),
    '#required' => TRUE,
    '#description' => 'The user metrics form can be set to appear sequentially before or after the Opinion Monitor\'s main content.',
  );
  $form['submit'] = array(
    '#type' => 'submit',
    '#value' => 'Save',
  );
  return $form;
}


/**
 * Form submission for opinion_monitor_admin_form()
 */
function opinion_monitor_admin_form_submit($form, $state) {
  // Save the user metrics options.
  variable_set('opinion_monitor_metrics_gender', $state['values']['metrics']['gender']);
  variable_set('opinion_monitor_metrics_age', $state['values']['metrics']['age']);
  variable_set('opinion_monitor_metrics_location', $state['values']['metrics']['location']);
  // Save the chart series colors.
  variable_set('opinion_monitor_chart_line_color_user', $state['values']['chart']['line_color_user']);
  variable_set('opinion_monitor_chart_line_color_average', $state['values']['chart']['line_color_average']);
  // Save the miscellaneous options.
  variable_set('opinion_monitor_use_module_css', $state['values']['misc']['use_module_css']);
  variable_set('opinion_monitor_use_drupal_jquery', $state['values']['misc']['use_drupal_jquery']);
  variable_set('opinion_monitor_user_metrics_location', $state['values']['misc']['user_metrics_location']);
}
