jQuery(function(){
  // Set some options for displaying the admin chart.
  var chartOptions = {
    width: 650,
    height: 300,
    curveType: 'function',
    tooltip: {
      showColorCode: false
    },
    vAxis: {
      title: 'Opinion',
      minValue: -1,
      maxValue: 1,
      format: '##%',
      viewWindowMode: 'explicit',
      viewWindow: {
        min: -1,
        max: 1
      },
      gridlines: {
        count: 3
      }
    },
    hAxis: {
      title: 'Content'
    }
  };

  jQuery('#opmon-results-select-opmon').change(function(){
    // Fire an AJAX request to get the list of questions relating to the selected Opinion Monitor.
    jQuery.ajax({
      type: 'POST',
      url: Drupal.settings.basePath + 'opmon/get_questions',
      data: 'opmon_id=' + jQuery(this).val(),
      dataType: 'json',
      success: function(response){
        // See if we've got enough data to draw the chart.
        if (response.data) {
          var select = jQuery('#opmon-results-select-question');
          if(select.prop) { // Forward-compatible jQuery code.
            var options = select.prop('options');
          }
          else {
            var options = select.attr('options');
          }
          jQuery('option', select).remove();
          jQuery.each(response.data, function(value, text) {
            options[options.length] = new Option(text, value);
          });
        }
        else {
          var select = jQuery('#opmon-results-select-question');
          if(select.prop) { // Forward-compatible jQuery code.
            var options = select.prop('options');
          }
          else {
            var options = select.attr('options');
          }
          jQuery('option', select).remove();
        }
      }
    });
  });
  jQuery('#opmon-results-select-opmon').change();

  jQuery('#opmon-results-compare').click(function(){
    var selectedOpmon = jQuery('#opmon-results-select-opmon').val();
    var selectedQuestion = jQuery('#opmon-results-select-question').val();
    var comparisonMetrics = jQuery('select[id^="opmon-results-select-"]');
    loadChart(selectedOpmon, selectedQuestion, comparisonMetrics, chartOptions);
  });

  // Load the chart data using AJAX and pass the data to the drawChart function if successful.
  // Note: Amend the chartOptions object above to pass Google Chart Tools API-specific options to the drawChart function.
  function loadChart(nidOpmon, nidQuestion, metrics, options) {
    // Collate the answers for this content's questions.
    var metricsQuery = '';
    jQuery.each(metrics, function(index, metric){
      metricsQuery = metricsQuery + '&' + jQuery(metric).attr('id') + '=' + jQuery(metric).val();
    });
    // Fire an AJAX request to get the stats and info we need to draw the chart.
    jQuery.ajax({
      type: 'POST',
      url: Drupal.settings.basePath + 'opmon/get_admin_results',
      data: 'opmon_id=' + nidOpmon + '&question_id=' + nidQuestion +  metricsQuery,
      dataType: 'json',
      success: function(response){
        // See if we've got enough data to draw the chart.
        if (response.data && response.data.length > 0) {
          drawChart(response.data, jQuery.extend(true, options, response.options));
          jQuery('#opmon-data-download-link').attr('href', Drupal.settings.basePath + 'opmon/export/' + nidOpmon);
          jQuery('#opmon-data-download-link').show();
        }
        else {
          jQuery('#opmon-results-chart').html('<p>Not enough data to draw a chart.</p>');
          jQuery('#opmon-data-download-link').hide();
        }
      },
      error: function(response){
        jQuery('#opmon-results-chart').html('<p>Unable to draw a chart at this time.</p>');
        jQuery('#opmon-data-download-link').hide();
      }
    });
  }

  // Draw a Google Chart based on the given data and using the given options.
  function drawChart(data, options) {
    // Create a DataTable from our raw data.
    dataTable = google.visualization.arrayToDataTable(data);
    // Tell the DataTable that the second column contains the custom tooltip content.
    dataTable.setColumnProperty(1, 'role', 'tooltip');
    // Create a custom DataView to aid drawing the raw DataTable.
    var dataView = new google.visualization.DataView(dataTable);
    // Prepare our DataView based on the number of columns in the DataTable.
    var numCols = dataTable.getNumberOfColumns();
    if (numCols == 3) {
      // There is only one data series.
      dataView.setColumns([0,2,1]);
    }
    if (numCols == 4) {
      // There are two data series, so follow each one with the tooltip column.
      dataView.setColumns([0,2,1,3,1]);
    }
    // Create our line chart and get it to draw the DataView.
    var chart = new google.visualization.LineChart(document.getElementById('opmon-results-chart'));
    chart.draw(dataView, options);
  }
});
