<?php

//------------------------------------------------------------------------------
// ENVIRONMENT SETUP
//------------------------------------------------------------------------------

// Include Google's AJAX API.
drupal_add_js('https://www.google.com/jsapi', array('type' => 'external'));
drupal_add_js("google.load('visualization', '1.0', {'packages':['corechart']});",
  array('type' => 'inline', 'scope' => 'header', 'weight' => 0)
);
drupal_add_js(drupal_get_path('module', 'opinion_monitor') . '/opinion_monitor_charts_user.js', array('type' => 'file', 'group' => JS_THEME));

//------------------------------------------------------------------------------
// DATA PREPARATION
//------------------------------------------------------------------------------

// Save the nid to a global so we can access it in the sub-themes.
global $opmon_id;
$opmon_id = $nid;

// Load the Opinion Monitor Content nodes associated with this opmon.
$opmon_contents = array();

// Get the items in the 'contents' field of the node.
$opmon_contents = field_get_items('node', $node, 'contents');

// Load an array of the current user's answers ready for us to use as default values for the form.
$answers = opmon_stats_get_all_user_answers($opmon_id);

// Load the opinion monitor metrics fields.
$metrics = opinion_monitor_get_metrics();

//------------------------------------------------------------------------------
// USER METRICS FORM
//------------------------------------------------------------------------------

$user_metrics_location = variable_get('opinion_monitor_user_metrics_location', 'below');
// Define a function for outputting the user metrics form when and where we want it.
function opmon_output_user_metrics_form($metrics) {
  // Only load the opinion monitor metrics form if we have some opinion monitor metrics to populate it with.
  if (!empty($metrics['gender']) || !empty($metrics['age']) || !empty($metrics['location'])) {
?>
    <div class="opmon-questions-wrapper">
      <h3><?php echo t('User Metrics'); ?></h3>
      <p class="description"><?php echo t('Please help us to enhance the usefulness of your answers by filling in the form below'); ?></p>
<?php echo drupal_render(drupal_get_form('opinion_monitor_prepare_frontend_metrics_form')); ?>
    </div>
<?php
  }
}

//------------------------------------------------------------------------------
// JAVASCRIPT
//------------------------------------------------------------------------------

// Output some useful values into the page's javascript.
?>
<script type="text/javascript">
var opmonNid = <?php echo $opmon_id; ?>;
var opmonValues = {};
<?php
// Write the current user's answers as a set of javascript objects.
foreach($answers as $nid_content => $content_answers) {
  $object_content = 'opmonValues.c_' . $nid_content . ' = {';
  foreach($content_answers as $nid_question => $answer) {
    $object_content .= 'q_' . $nid_question . ' : ' . $answer . ', ';
  }
  $object_content = substr($object_content, 0, -2) . "};\n";
  echo $object_content;
}
?>
</script>

<?php

//------------------------------------------------------------------------------
// OPINION MONITOR NODE
//------------------------------------------------------------------------------

?>
<div id="node-<?php echo $nid; ?>" class="node-opmon node<?php if ($sticky) { echo ' sticky'; } ?><?php if (!$status) { echo ' node-unpublished'; } ?>">
<?php
// Is this a listing page?
if ($page == 0) { // TODO: Can use a 'teaser' variable instead? Check Vital node templates.
?>
  <h2><a href="<?php echo $node_url; ?>" title="<?php echo $title; ?>"><?php echo $title; ?></a></h2>
  <p class="description"><?php echo format_plural(count($opmon_contents), '1 ' . t('Section'), '@count ' . t('Sections')); ?></p>
  <div>
<?php echo $body[0]['value']; ?>
  </div>
<?php
/*
  // Output the "read more" link.
  if (array_key_exists('node', $content['links'])) {
?>
  <div class="opmon-readmore"><?php
  echo render($content['links']['node']);
?></div>
<?php
  }
*/
}
// Is this a normal page?
else {
?>

  <div>
<?php
// Output the Opinion Monitor node's content - this is the 'preview' of the opmon.
echo $body[0]['value'];
?>
  </div>

<?php

  // Conditionally output the user metrics form here, depending on the admin setting.
  if ($user_metrics_location == 'above') {
    opmon_output_user_metrics_form($metrics);
  }

  //----------------------------------------------------------------------------
  // OPINION MONITOR CONTENT NODES
  //----------------------------------------------------------------------------

  // Output each Opinion Monitor Content node as an element in an ordered list.
?>
  <ol id="opmon-contents">
<?php
  // Loop through the list of Opinion Monitor Content nodes and output them.
  foreach ($opmon_contents as $opmon_content) {
?>
    <li id="opmon-content-<?php echo $opmon_content['target_id']; ?>">
<?php
    // Output the Opinion Monitor Content nodes using Drupal's theme() function.
    $c_node = node_load($opmon_content['target_id']);
    echo drupal_render(node_view($c_node));
?>
    </li>
<?php
  }
?>
  </ol>

<?php

  // Conditionally output the user metrics form here, depending on the admin setting.
  if ($user_metrics_location == 'below') {
    opmon_output_user_metrics_form($metrics);
  }

  //----------------------------------------------------------------------------
  // COMPARISON CHART
  //----------------------------------------------------------------------------

?>

  <div class="opmon-results">
    <h3><?php echo t('How I Compare'); ?></h3>
    <p class="description"><?php echo t('Use this form to discover how your answers to the Opinion Monitor compare to those of others'); ?></p>

    <div class="opmon-question-wrapper">
      <p class="description"><?php echo t('Choose a question from the list to compare:'); ?></p>
      <label for="opmon-results-select-question"><?php echo t('Question:'); ?></label>
      <select id="opmon-results-select-question">
<?php
  // Get a list of all the questions associated with this opmon. We can get this list from the table of questions that have been answered ({opinion_monitor_responses}).
  $questions = opmon_get_available_questions($opmon_id);
  foreach ($questions as $question_nid => $question_title) {
?>
        <option value="<?php echo $question_nid; ?>"><?php echo htmlentities($question_title); ?></option>
<?php
  }
?>
      </select>

<?php

  // Only load the opinion monitor metrics form if we have some opinion monitor metrics to populate it with.
  if (!empty($metrics['gender']) || !empty($metrics['age']) || !empty($metrics['location'])) {
    // Add an '-- All --' option to the start of the various metrics.
    $metrics_list = $metrics;
    foreach ($metrics_list as &$metric) {
      $metric = array_merge(array('-- All --' => t('-- All --')), $metric);
    }

?>
      <p class="description"><?php echo t('Choose options to narrow your comparison:'); ?></p>
<?php
    if (!empty($metrics['gender'])) {
?>
      <label for="opmon-results-select-gender"><?php echo t('Gender:'); ?></label>
      <select id="opmon-results-select-gender">
<?php
      foreach ($metrics_list['gender'] as $gender_key => $gender) {
        echo '<option value="' . htmlentities($gender_key) . '">' . htmlentities($gender) . '</option>' . "\n";
      }
?>
      </select>
<?php
    }
?>

<?php
    if (!empty($metrics['age'])) {
?>
      <label for="opmon-results-select-age"><?php echo t('Age:'); ?></label>
      <select id="opmon-results-select-age">
<?php
      foreach ($metrics_list['age'] as $age) {
        echo '<option value="' . htmlentities($age) . '">' . htmlentities($age) . '</option>' . "\n";
      }
?>
      </select>
<?php
    }
?>

<?php
    if (!empty($metrics['location'])) {
?>
      <label for="opmon-results-select-location"><?php echo t('Location:'); ?></label>
      <select id="opmon-results-select-location">
<?php
    foreach ($metrics_list['location'] as $location) {
      echo '<option value="' . htmlentities($location) . '">' . htmlentities($location) . '</option>' . "\n";
    }
?>
      </select>
<?php
    }
  }
?>
      <input type="button" id="opmon-results-compare" value="Compare" />

      <!-- A DIV for drawing the charts -->
      <div id="opmon-results-chart-wrapper">
        <div id="opmon-results-chart"></div>
      </div>
    </div>
  </div>
</div>

<?php
}
?>
